## v1.1.4:

* [COOK-2146] - style updates

## v1.1.2:

* [COOK-1989] - fix scope for handler local variable to the enable block

## v1.1.0:

* [COOK-1645] - properly delete old handlers
* [COOK-1322] - support platforms that use 'wheel' as root group'

## v1.0.8:

* [COOK-1177] - doesn't work on windows due to use of unix specific attributes
## v1.0.6:

* [COOK-1069] - typo in chef_handler readme

## v1.0.4:

* [COOK-654] dont try and access a class before it has been loaded
* fix bad boolean check (if vs unless)

## v1.0.2:

* [COOK-620] ensure handler code is reloaded during daemonized chef runs
